Subject: Re: port-i386/19163: VIA C3 processor isn't recognized correctly
To: Takahiro Kambe <taca@back-street.net>
From: Bang Jun-Young <junyoung@netbsd.org>
List: netbsd-bugs
Date: 12/05/2002 12:00:54
On Tue, Nov 26, 2002 at 12:15:45AM +0900, Takahiro Kambe wrote:
> cpu0 at mainbus0: (uniprocessor)
> cpu0: IDT Pentium Pro compatible (686-class), 533.39 MHz
> cpu0: features 803035<FPU,DE,TSC,MSR,MTRR>
> cpu0: features 803035<PGE,MMX>

Could you test with the following patch?

Index: machdep.c
===================================================================
RCS file: /cvsroot/syssrc/sys/arch/i386/i386/machdep.c,v
retrieving revision 1.498
diff -u -r1.498 machdep.c
--- machdep.c	2002/11/22 15:23:41	1.498
+++ machdep.c	2002/12/04 17:42:44
@@ -959,19 +959,20 @@
 			NULL,
 			NULL,
 		},
-		/* Family 6, not yet available from IDT */
+		/* Family 6 */
 		{
 			CPUCLASS_686,
 			{
-				0, 0, 0, 0, 0, 0, 0, 0,
-				0, 0, 0, 0, 0, 0, 0, 0,
-				"Pentium Pro compatible"	/* Default */
+				0, 0, 0, 0, 0, 0, "C3 Samuel",
+				"C3 Samuel 2/Ezra", "C3 Ezra-T",
+				0, 0, 0, 0, 0, 0, 0,
+				"C3"	/* Default */
 			},
 			NULL,
 			NULL,
 			NULL,
 		},
 		/* Family > 6, not yet available from IDT */
 		{
 			CPUCLASS_686,
 			{
@@ -1750,6 +1751,9 @@
 				else
 					brand = amd_brand_name;
 			}
+			
+			if (vendor == CPUVENDOR_IDT && family >= 6)
+				vendorname = "VIA";
 		}
 	}
 
@@ -959,19 +959,20 @@
 			NULL,
 		},
-		/* Family > 6, not yet available from IDT */
+		/* Family > 6, not yet available from VIA */
 		{
 			CPUCLASS_686,
Jun-Young

-- 
Bang Jun-Young <junyoung@netbsd.org>